#
# spec file for package evolution-ews
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


# _version needs to be %%{version} stripped to major.minor.micro only...
%define _version %(echo %{version} | grep -E -o '[0-9]+\.[0-9]+\.[0-9]+')

Name:           evolution-ews
Version:        3.34.4
Release:        lp152.2.3.1
Summary:        Exchange Connector for Evolution, compatible with Exchange 2007 and later
License:        LGPL-2.1-only
Group:          Productivity/Networking/Email/Clients
URL:            https://wiki.gnome.org/Apps/Evolution
Source0:        https://download.gnome.org/sources/evolution-ews/3.34/%{name}-%{version}.tar.xz
# PATCH-FIX-UPSTREAM evolution-ews-boo1182882.patch boo#1182882 mgorse@suse.com -- fix buffer overrun when decoding base64 data.
Patch0:         evolution-ews-boo1182882.patch

BuildRequires:  c++_compiler
BuildRequires:  cmake
BuildRequires:  fdupes
BuildRequires:  intltool
BuildRequires:  pkgconfig
BuildRequires:  translation-update-upstream
BuildRequires:  pkgconfig(camel-1.2) >= %{_version}
BuildRequires:  pkgconfig(evolution-calendar-3.0) >= %{_version}
BuildRequires:  pkgconfig(evolution-data-server-1.2) >= %{_version}
BuildRequires:  pkgconfig(evolution-mail-3.0) >= %{_version}
BuildRequires:  pkgconfig(evolution-shell-3.0) >= %{_version}
BuildRequires:  pkgconfig(glib-2.0) >= 2.46
BuildRequires:  pkgconfig(gtk+-3.0) >= 3.10
BuildRequires:  pkgconfig(libebackend-1.2) >= %{_version}
BuildRequires:  pkgconfig(libebook-1.2) >= %{_version}
BuildRequires:  pkgconfig(libecal-2.0) >= %{_version}
BuildRequires:  pkgconfig(libedata-book-1.2) >= %{_version}
BuildRequires:  pkgconfig(libedata-cal-2.0) >= %{_version}
BuildRequires:  pkgconfig(libedataserver-1.2) >= %{_version}
BuildRequires:  pkgconfig(libemail-engine) >= %{_version}
BuildRequires:  pkgconfig(libical)
BuildRequires:  pkgconfig(libmspack) >= 0.4
BuildRequires:  pkgconfig(libsoup-2.4) >= 2.42

%description
The EWS Exchange Connector for Evolution provides a Exchange
backend from evolution-data-server as well as plugins for Evolution
to access Exchange features.

The EWS Exchange Connector is using the Exchange Web Services
interface and is therefore compatible with Exchange 2007 and later.

Provides exchange connectivity for exchange server 2007 and later
using exchange web services protocol.

%lang_package

%prep
%autosetup -p1
translation-update-upstream

%build
%cmake \
  -DCMAKE_SKIP_RPATH=OFF \
  -DCMAKE_BUILD_WITH_INSTALL_RPATH=ON
%cmake_build

%install
%cmake_install
%find_lang %{name} %{?no_lang_C}
%fdupes %{buildroot}%{_datadir}

%files
%license COPYING
%doc README
%{_libdir}/evolution-data-server/addressbook-backends/libebookbackendews.so
%{_libdir}/evolution-data-server/calendar-backends/libecalbackendews.so
%{_libdir}/evolution-data-server/camel-providers/libcamelews.so
%{_libdir}/evolution-data-server/camel-providers/libcamelews.urls
%{_libdir}/evolution-data-server/registry-modules/module-ews-backend.so
%{_libdir}/evolution/modules/module-ews-configuration.so
%dir %{_libdir}/%{name}
%{_libdir}/%{name}/libcamelews-priv.so
%{_libdir}/%{name}/libevolution-ews.so
%{_datadir}/evolution/errors/module-ews-configuration.error
%dir %{_datadir}/evolution-data-server/ews
%{_datadir}/evolution-data-server/ews/windowsZones.xml
%{_datadir}/metainfo/org.gnome.Evolution-ews.metainfo.xml

%files lang -f evolution-ews.lang

%changelog
* Wed Mar  3 2021 Michael Gorse <mgorse@suse.com>
- Add evolution-ews-boo1182882.patch: fix buffer overrun when
  parsing base64 data (boo#1182882).
* Fri Feb 14 2020 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.34.4:
  + Bugs fixed:
  - Fails to create event with no duration.
  - Map 'tzone://Microsoft/Utc' to libical's 'UTC'.
* Sun Jan  5 2020 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.34.3:
  + Bug Fixes: glgo#GNOME-evolution-ews#81: Attachment flag not
    shown on messages with attachment.
* Fri Nov 22 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.34.2:
  + Some meetings shown as plain events.
  + Disconnect signal handlers on connection object in dispose of
    book/calendar backend.
  + Bugs fixed: glgo#GNOME/evolution-ews#64,
    glgo#GNOME/evolution-ews#70.
* Mon Oct  7 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.34.1:
  + Prefill email address as user name when creating new account.
  + Autodiscover: Do not change user name with RedirectAddr.
  + Bugs fixed: glgo#GNOME/evolution-ews#65,
    glgo#GNOME/evolution-ews#66, glgo#GNOME/evolution-ews#69,
    glgo#GNOME/evolution-ews#71.
  + Updated translations.
* Mon Sep 16 2019 Michael Gorse <mgorse@suse.com>
- Pass --DCMAKE_SKIP_RPATH=OFF and
  - DCMAKE_BUILD_WITH_INSTALL_RPATH=ON to cmake again. Otherwise,
  the EDS backends don't have the library directory in their rpath.
* Mon Sep  9 2019 mgorse@suse.com
- Update to version 3.34.0:
  + No code/translation changes.
* Sat Sep  7 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Replace pkgconfig(libedata-cal-1.2) with
  pkgconfig(libedata-cal-2.0) BuildRequires following upstreams
  changes.
- Use autosetup and cmake_build macros.
- Stop passing -DCMAKE_SKIP_RPATH=OFF and
  - DCMAKE_BUILD_WITH_INSTALL_RPATH=ON to cmake, no longer needed.
- Replace gcc-c++ with the genric c++_compiler BuildRequires.
* Thu Sep  5 2019 luke@ljones.dev
- Update to version 3.33.92:
  + Fix a memory leak in camel_ews_store_ensure_virtual_folders().
  + Bugs fixed: glgo#GNOME/evolution-ews#60.
- Update to version 3.33.91:
  + Bugs fixed: glgo#GNOME/evolution-ews#55,
    glgo#GNOME/evolution-ews#56, glgo#GNOME/evolution-ews#57.
- Update to version 3.33.4:
  + Fix few memory leaks in e_cal_backend_ews_rid_to_index()
  + Count with an ICalTimezone without internal component in
    ewscal_set_availability_timezone().
  + Categories property cannot be deleted.
  + Bugs fixed: glgo#GNOME/evolution-ews#53.
- Update to version 3.33.3:
  + Fix issues found during 'make check'.
  + Fix some compiler warnings reported by Clang in the test code.
  + Bugs fixed: glgo#GNOME/evolution-ews#42,
    glgo#GNOME/evolution-ews#49.
- Update to version 3.33.2:
  + Add refresh interval options to non-mail sources.
  + Port to libecal-2.0 and adapt to address book API changes.
- Update to version 3.33.1:
  + Use lower-case "mailto:" consistently in the code.
  + Bugs fixed: glgo#GNOME/evolution-ews#41,
    glgo#GNOME/evolution-ews#39.
* Mon May  6 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.32.2:
  + Use lower-case "mailto:" consistently in the code.
* Wed Apr 10 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.32.1:
  + Let handle recurring task completion by the server.
  + Unreachable EWS service causes Calendar(s) to disappear.
  + Do not pass 'scope' parameter in OAuth2 requests on
    outlook.office365.com server.
  + Updated translations.
* Mon Mar 11 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.32.0:
  + Updated translations.
* Tue Feb 19 2019 bjorn.lie@gmail.com
- Update to version 3.31.91:
  + Implement 'exists' ESExp function in the book backend.
- Changes from version 3.31.90:
  + Use also -DCAMEL_DISABLE_DEPRECATED=1 in the maintainer mode.
  + Bugs fixed: glgo#GNOME/evolution-ews#25,
    glgo#GNOME/evolution-ews#30, glgo#GNOME/evolution-ews#31,
    glgo#GNOME/evolution-ews#32.
  + Updated translations.
* Sat Feb  9 2019 bjorn.lie@gmail.com
- Update to version 3.31.4:
  + Updated translations.
* Sat Feb  9 2019 bjorn.lie@gmail.com
- Update to version 3.31.3:
  + Fix a build break with glib pre-2.54 and bump libsoup version
    to 2.58.
  + Correct how extra compiler warnings are used in the maintainer
    mode.
  + Bugs fixed: glgo#GNOME/evolution-ews#27,
    glgo#GNOME/evolution-ews#54.
  + Updated translations.
- Changes from version 3.31.2:
  + Make sure intltool-merge cache is created only once.
  + Bugs fixed: glgo#GNOME/evolution-ews#17,
    glgo#GNOME/evolution-ews#18, glgo#GNOME/evolution-ews#23,
    glgo#GNOME/evolution-ews#24.
  + Updated translations.
- Changes from version 3.31.2:
  + Calendar invites added with the wrong time zone.
  + Fix an invalid unref call and a memory leak of an
    EEwsConnection object.
  + Enable only Notification reminders in the calendar.
  + Treat 'Unknown' ResponseType as Needs-Action.
  + Collection backend schedules two 'populate' requests after
    going online.
  + Bugs fixed: glgo#GNOME/evolution-ews#8,
    glgo#GNOME/evolution-ews#14, glgo#GNOME/evolution-ews#19,
    glgo#GNOME/evolution-ews#21.
  + Updated translations.
* Fri Feb  8 2019 bjorn.lie@gmail.com
- Update to version 3.30.5:
  + Bugs fixed: glgo#GNOME/evolution-ews#25,
    glgo#GNOME/evolution-ews#30, glgo#GNOME/evolution-ews#31,
    glgo#GNOME/evolution-ews#32.
- Changes from version 3.30.4:
  + Updated translations.
* Mon Dec 10 2018 bjorn.lie@gmail.com
- Update to version 3.30.3:
  + Make sure intltool-merge cache is created only once.
  + Calendar: Retry item download on ErrorBatchProcessingStopped
    error.
* Sat Nov 17 2018 bjorn.lie@gmail.com
- Drop pkgconfig(enchant) BuildRequires: No longer needed.
* Wed Oct 24 2018 bjorn.lie@gmail.com
- Update to version 3.30.2:
  + Enable only Notification reminders in the calendar.
  + Treat 'Unknown' ResponseType as Needs-Action.
  + Collection backend schedules two 'populate' requests after
    going online.
  + Bugs fixed: glgo#GNOME/evolution-ews#18,
    glgo#GNOME/evolution-ews#19, glgo#GNOME/evolution-ews#21,
    glgo#GNOME/evolution-ews#23.
  + Updated translations.
* Wed Sep 26 2018 bjorn.lie@gmail.com
- Update to version 3.30.1:
  + Calendar invites added with the wrong time zone.
  + Fix an invalid unref call and a memory leak of an
    EEwsConnection object.
  + Bugs fixed: glgo#GNOME/evolution-ews!8,
    glgo#GNOME/evolution-ews!14.
  + Updated translations.
* Wed Sep 19 2018 luc14n0@linuxmail.org
- Update to version 3.30.0:
  + No visible changes for the user.
- Update spec:
  + Drop lang subpackage Recommends: the main package is already
    being supplemented by the lang subpackage due to RPM automatic
    setting.
* Wed Aug 29 2018 bjorn.lie@gmail.com
- Update to version 3.29.92:
  + Updated translations.
* Mon Aug 13 2018 bjorn.lie@gmail.com
- Update to version 3.29.91:
  + Updated translations.
* Wed Aug  1 2018 bjorn.lie@gmail.com
- Update to version 3.29.90:
  + Bugs fixed: glgo#GNOME/evolution-ews#10,
    glgo#GNOME/evolution-ews#11.
  + Updated translations.
* Wed Aug  1 2018 luc14n0@linuxmail.org
- Update to version 3.29.4:
  + Miscellaneous: Fix a few memory leaks.
  + Bugs fixed: bgo#796297, glgo#GNOME/evolution-ews#12,
    glgo#GNOME/evolution-ews#4, glgo#GNOME/evolution-ews#5,
    glgo#GNOME/evolution-ews#2, glgo#GNOME/evolution-ews#6,
    glgo#GNOME/evolution-ews#7.
  + Updated translations.
* Wed Aug  1 2018 bjorn.lie@gmail.com
- Update to version 3.29.3:
  + Update a maintainer in the DOAP file.
  + Update bug URL and switch to https:// in the DOAP file.
  + Missing build dependency for gdbus-codegen on input .xml file.
  + Bugs fixed: bgo#796297, bgo#795870.
* Wed Aug  1 2018 luc14n0@linuxmail.org
- Update to version 3.29.2:
  + Miscellaneous:
  - Crash when meeting invitation iCalendar part could not be
    parsed;
  - Skip empty street addresses in contacts;
  - Stale connection used after resume;
  + Bug Fixes: bgo#795329, bgo#795121, bgo#792653, bgo#795414.
  + Updated translations.
* Wed Aug  1 2018 luc14n0@linuxmail.org
- Update to version 3.29.1:
  + Miscellaneous: Make it possible to disable Reminders for Tasks.
  + Bug Fixes:
  - Support recurrence task (bgo#654459).
  - [Contacts] Use 'Display Name' as 'File As' when 'File As' is
    missing (bgo#795076).
  + Updated translations.
* Tue Jul 31 2018 bjorn.lie@gmail.com
- Update to version 3.28.5:
  + Bugs fixed: glgo#GNOME/evolution-ews#10.
  + Updated translations.
* Mon Jul 16 2018 bjorn.lie@gmail.com
- Update to version 3.28.4:
  + Bugs fixed: bgo#796297, glgo#GNOME/evolution-ews#12,
    glgo#GNOME/evolution-ews#4, glgo#GNOME/evolution-ews#5,
    glgo#GNOME/evolution-ews#2, glgo#GNOME/evolution-ews#7.
* Mon Jun 18 2018 bjorn.lie@gmail.com
- Update to version 3.28.3:
  + Address some of the compiler and static analyzers warnings.
  + Update bug URL and switch to https:// in the DOAP file.
  + Bugs fixed: bgo#796297.
* Mon May  7 2018 bjorn.lie@gmail.com
- Update to version 3.28.2:
  + Crash when meeting invitation iCalendar part could not be
    parsed.
  + Skip empty street addresses in contacts.
  + Stale connection used after resume.
  + Bugs fixed: bgo#795076, bgo#795329, bgo#795414.
  + Updated translations.
* Mon Apr  9 2018 bjorn.lie@gmail.com
- Update to version 3.28.1:
  + Bugs fixed: bgo#794116, bgo#788202, bgo#794924, bgo#794815.
  + Updated translations.
* Tue Mar 20 2018 dimstar@opensuse.org
- Unconditionally enable translation-update-upstream: on
  Tumbleweed, this results in a NOP and for Leap in SLE paid
  translations being used (boo#1086036).
* Mon Mar 12 2018 bjorn.lie@gmail.com
- Update to version 3.28.0:
  + Updated translations.
* Tue Mar  6 2018 dimstar@opensuse.org
- Update to version 3.27.92:
  + Miscellaneous: Fix runtime warning when attendee has no
    ResponseType.
  + Bugs fixed: bgo#763455, bgo#793606.
  + Updated translations.
* Tue Mar  6 2018 dimstar@opensuse.org
- Modernize spec-file by calling spec-cleaner
* Tue Mar  6 2018 dimstar@opensuse.org
- Update to version 3.27.91:
  + Correct possible scope for Office365 OAuth2.
  + Add translator comments around 'Tenant' word.
  + Check validity of returned values in 'Folder Sizes' function.
  + Various changes related to outlook.office365.com server.
  + Office365.com OAuth2: Relax the 'prompt' user interaction type.
  + Bugs fixed: bgo#775690, bgo#793104, bgo#793368.
  + Updated translations.
* Tue Mar  6 2018 dimstar@opensuse.org
- Update to version 3.27.90:
  + bgo#792411: Use GetUserPhoto to lookup sender's photo.
  + bgo#793037: Some appointments displayed as meetings.
  + bgo#775690: Support OAuth2 for outlook.office365.com.
  + Updated translations.
* Tue Mar  6 2018 dimstar@opensuse.org
- Update to version 3.27.4:
  + Miscellaneous: Ignore address books with UUID-like name.
  + Bugs fixed: bgo#792190.
  + Updated translations.
* Tue Mar  6 2018 luc14n0@linuxmail.org
- Update to version 3.27.3:
  + Miscellaneous:
  - [ECalBackendEws] Prevent crash when item has no MIME content
    set.
  - Correct arguments of g_dngettext() added in the previous
    commit.
  + Bug Fix: Check response headers for credential expiration
    hints (bgo#790450).
  + Updated translations.
- Adopt the use of %%make_jobs macro rather than raw make command,
  following the best practices.
- Point fdupes to the data directory instead of the build root,
  which is a practice that must be avoided.
* Tue Mar  6 2018 fezhang@suse.com
- Update to version 3.27.2:
  + Prevent crash under ews_backend_sync_created_folders().
  + Synchronize authentication extensions before creating an
    ESource.
  + Bugs fixed: bgo#760329.
  + Updated translations.
* Tue Mar  6 2018 luc14n0@linuxmail.org
- Update to version 3.27.1:
  + Miscellaneous:
  - Adapt to rename of evolution.desktop to
    org.gnome.Evolution.desktop.
  - Use icaltime_is_utc() instead of icaltimetype::is_utc.
  + Bug Fixes:
  - After pressing "NOT JUNK" mail stays in the Junk folder
    (bgo#786982).
  - Skip GSettings schema compile when DESTDIR is set
    (bgo#781645).
  - Deadlock when trying to save changes after vFolder's thaw
    (bgo#788782).
  + Updated translations.
- Updated Url to https://wiki.gnome.org/Apps/Evolution: current
  evolution's wiki page.
- Add conditional use to translation-update-upstream: SLE-only
  requirement.
* Mon Mar  5 2018 bjorn.lie@gmail.com
- Update to version 3.26.6:
  + Bugs fixed: bgo#793606.
* Mon Feb  5 2018 bjorn.lie@gmail.com
- Update to version 3.26.5:
  + Bugs fixed: bgo#793037.
* Mon Jan  8 2018 zaitor@opensuse.org
- Update to version 3.26.4:
  + Bugs fixed: bgo#792190.
* Wed Dec 20 2017 zaitor@opensuse.org
- Update to version 3.26.3:
  + [ECalBackendEws] Prevent crash when item has no MIME content
    set.
  + Updated translations.
* Wed Nov  1 2017 dimstar@opensuse.org
- Update to version 3.26.2:
  + Use icaltime_is_utc() instead of icaltimetype::is_utc.
  + Prevent crash under ews_backend_sync_created_folders().
  + Bugs fixed: bgo#781645, bgo#788782.
  + Updated translations.
* Mon Oct  2 2017 zaitor@opensuse.org
- Update to version 3.26.1:
  + Escape spaces in server Categories for message Labels.
  + Bugs fixed: bgo#786208.
* Mon Sep 11 2017 dimstar@opensuse.org
- Update to version 3.26.0:
  + No code/translation changes.
* Wed Sep  6 2017 dimstar@opensuse.org
- Update to version 3.25.92.2:
  + Do not use PROJECT_VERSION_TWEAK when searching for eds/evo
    dependencies.
- Changes from version 3.25.92.1:
  + Revert "Adapt to rename of evolution.desktop to
    org.gnome.Evolution.desktop".
- Changes from version 3.25.92:
  + Adapt to rename of evolution.desktop to
    org.gnome.Evolution.desktop.
  + Bugs fixed: bgo#782826, bgo#786095.
  + Updated translations.
* Mon Aug 21 2017 zaitor@opensuse.org
- Update to version 3.25.91:
  + Updated translations.
* Tue Aug  8 2017 zaitor@opensuse.org
- Update to version 3.25.90:
  + Bugs fixed: bgo#785188, bgo#750564.
  + Updated translations.
- Changes from version 3.25.4:
  + Fix a crash on local cache update of a GAL from OAB.
  + Bugs fixed: bgo#625149, bgo#783987, bgo#784332, bgo#784058,
    bgo#784775.
  + Updated translations.
* Tue Aug  8 2017 dimstar@opensuse.org
- Update to version 3.25.3:
  + e_ews_connection_try_credentials_sync() asks for password when
    not needed.
  + Derive from EBookMetaBackend and ECalMetaBackend.
  + Allow overwrite of CMAKE_SKIP_RPATH variable.
  + Allow adding Free/Busy as a foreign Calendar (bgo#782826).
  + Updated translations.
- Drop evolution_base_version defines: no longer required.
* Tue Aug  8 2017 zaitor@opensuse.org
- Update to version 3.25.2:
  + Bug fixed: bgo#781833.
* Tue Aug  8 2017 dimstar@opensuse.org
- Update to version 3.25.1:
  + No changes, version bump only.
* Mon Aug  7 2017 zaitor@opensuse.org
- Update to version 3.24.5:
  + Bugs fixed: bgo#785188.
  + Updated translations.
* Mon Jul 17 2017 zaitor@opensuse.org
- Update to version 3.24.4:
  + Bugs fixed: bgo#784332, bgo#784058, bgo#784775.
  + Updated translations.
* Mon Jun 19 2017 zaitor@opensuse.org
- Update to version 3.24.3:
  + e_ews_connection_try_credentials_sync() asks for password when
    not needed.
  + Allow overwrite of CMAKE_SKIP_RPATH variable.
- Pass -DCMAKE_SKIP_RPATH=OFF to configure, needed after upstream
  changes.
* Wed May 10 2017 zaitor@opensuse.org
- Update to version 3.24.2:
  + Bugs fixed: bgo#781833.
  + Updated translations.
* Wed Apr 19 2017 zaitor@opensuse.org
- Update to version 3.24.1:
  + Sources always enabled, even when their part is disabled.
  + Use correct respond method in
    e_cal_backend_ews_remove_object().
  + Bugs fixed: bgo#779804, bgo#780391.
  + Updated translations.
* Mon Mar 20 2017 dimstar@opensuse.org
- Update to version 3.24.0:
  + No code/translation changes.
* Mon Mar 13 2017 dimstar@opensuse.org
- Update to version 3.23.92:
  + Updated translations.
* Mon Feb 27 2017 zaitor@opensuse.org
- Update to version 3.23.91:
  + Updated translations.
* Wed Feb 15 2017 dimstar@opensuse.org
- Update to version 3.23.90:
  + Avoid local message cache expiry clean up when being offline.
  + Bug fixed: bgo#777946.
  + Updated translations.
* Wed Feb 15 2017 dimstar@opensuse.org
- Update to version 3.23.4:
  + Fix possible uninitialized variable usage in
    ews-test-timezones.c.
  + Fix few memory leaks.
  + Fix "variable may be used uninitialized" warning in
    query-to-restriction conversion.
  + Bugs fixed: bgo#773419, bgo#775649, bgo#775951, bgo#777021.
  + Updated translations.
* Wed Feb 15 2017 dimstar@opensuse.org
- Update to version 3.23.3:
  + Autodiscover can cause deadlock in GCancellable code.
  + Make glib_mkenums() files depend on the source enum file.
  + Bugs fixed: bgo#774364, bgo#775363, bgo#775395.
  + Updated translations.
- Drop evolution-ews-rpath.patch: fixed upstream.
* Wed Feb 15 2017 dimstar@opensuse.org
- Update to version 3.23.2:
  + Runtime warnings when calling ResolveNames.
  + Do not require C++ compiler, when not used.
  + Ensure CMAKE_SKIP_RPATH is OFF, the RPATH is used here.
  + Bugs fixed: bgo#764065, bgo#769573, bgo#773379, bgo#774523.
- Add evolution-ews-rpath.patch: Allow to build directly with
  final runpath.
* Wed Feb 15 2017 dimstar@opensuse.org
- Update to version 3.23.1:
  + Convert from autotools to CMake.
  + Require as hard dependency some dependencies.
  + Add a helper script for a 'dist' target.
  + Rename SHARE_INSTALL_DIR to SHARE_INSTALL_PREFIX.
  + Use tests/ as `make check` tests, if enabled with ENABLE_TESTS.
  + Hard-break `make dist` when there are uncommitted changes.
  + Updated translations.
- Replace %%%%configure call with %%%%cmake, following upstreams port.
- Add pkgconfig()-style BuildRequires, matching what configure
  checks for: camel-1.2, evolution-calendar-3.0, libebook-1.2,
  libecal-1.2, libical.
- Drop definition of evolution_base_version: it's not been used for
  a while in evolution-ews.
- Drop libeews-1_2-0, libewsutils0 and -devel subpackages: there is
  no public API to be consumed anymore (and nothing ever did or was
  supposed to).
* Mon Feb 13 2017 zaitor@opensuse.org
- Update to version 3.22.5:
  + Bugs fixed: bgo#777946.
* Tue Jan 17 2017 zaitor@opensuse.org
- Update to version 3.22.4:
  + Fix few memory leaks.
  + Bugs fixed: bgo#775951, bgo#775649.
* Mon Dec 12 2016 zaitor@opensuse.org
- Update to version 3.22.3:
  + Autodiscover can cause deadlock in GCancellable code.
* Mon Nov  7 2016 zaitor@opensuse.org
- Update to version 3.22.2:
  + Runtime warnings when calling ResolveNames.
  + Bugs fixed: bgo#770936, bgo#738093, bgo#773379.
* Mon Oct 10 2016 zaitor@opensuse.org
- Update to version 3.22.1:
  + Bugs fixed: bgo#771370, bgo#771931.
* Mon Sep 19 2016 zaitor@opensuse.org
- Update to version 3.22.0:
  + Updated translations.
* Mon Sep 12 2016 zaitor@opensuse.org
- Update to version 3.21.92:
  + Do not restrict/remove From address on message send
    (bgo#758374).
  + Updated translations.
* Mon Aug 29 2016 dimstar@opensuse.org
- Update to version 3.21.91:
  + Updated translations.
* Mon Aug 15 2016 zaitor@opensuse.org
- Update to version 3.21.90:
  + Customized timezones not recognized (bgo#769044).
  + Updated translations.
* Mon Aug  8 2016 zaitor@opensuse.org
- Update to version 3.21.4:
  + Always build ESExp structure as a GObject descendant.
  + Add Language headers to po files.
  + Bugs fixed: bgo#764065.
  + Updated translations.
* Mon Aug  8 2016 zaitor@opensuse.org
- Update to version 3.21.3:
  + Initialize connection variable to NULL in
    camel_ews_folder_get_message().
  + Fix a memory leak when creating a contact.
  + Address some of the clang compiler warnings.
  + Bugs fixed: bgo#767030, bgo#722193, bgo#767335, bgo#634294.
  + Updated translations.
* Mon Aug  8 2016 zaitor@opensuse.org
- Update to version 3.21.2:
  + Fix some issues found by Coverity Scan.
  + Bugs fixed: bgo#765398, bgo#766021.
  + Updated translations.
* Mon Aug  8 2016 zaitor@opensuse.org
- Update to version 3.21.1:
  + Ask for password after NTLM/SSO authentication failure.
  + Bugs fixed: bgo#763991, bgo#764110, bgo#764977, bgo#764976,
    bgo#765209.
  + Updated translations.
- Drop evolution-ews-ntlm-auth-test-failure.patch: Fixed upstream.
- Bump base version following upstream changes.
* Mon Aug  8 2016 zaitor@opensuse.org
- Update to version 3.20.5:
  + Customized timezones not recognized (bgo#769044).
* Mon Jul 11 2016 zaitor@opensuse.org
- Update to version 3.20.4:
  + Bugs fixed: bgo#722193, bgo#767335, bgo#634294.
  + Updated translations.
* Tue Jun  7 2016 badshah400@gmail.com
- Update to version 3.20.3:
  + Fix some issues found by Coverity Scan.
  + Initialize connection variable to NULL in
    camel_ews_folder_get_message().
  + Bugs fixed: bgo#766021, bgo#767030.
* Tue May 17 2016 mgorse@suse.com
- Update to GNOME 3.20.2  Fate#318572
* Tue May 10 2016 zaitor@opensuse.org
- Update to version 3.20.2:
  + Ask for password after NTLM/SSO authentication failure.
  + Bugs fixed: bgo#764976, bgo#765209, bgo#765398.
- Drop evolution-ews-ntlm-auth-test-failure.patch: Fixed upstream.
* Fri Apr 22 2016 zaitor@opensuse.org
- Add evolution-ews-ntlm-auth-test-failure.patch: Fix NTLM auth
  failure with latest samba. Fixes boo#976110, bgo#765106.
* Thu Apr 14 2016 mgorse@suse.com
- Update to GNOME 3.20  Fate#318572
- Drop ews-timezone.patch,
  evolution-ews-3.10.4-foreign-calendars-hidden.patch
  evolution-ews-3.10.4-remove-sources.patch, and
  evolution-ews-3.10.4-Permissions-on-context-menu-for-GAL.patch:
  fixed upstream.
* Mon Apr 11 2016 zaitor@opensuse.org
- Update to version 3.20.1:
  + Add thread safety around ECalBackendEws::priv::cancellable.
  + Bugs fixed: bgo#763719, bgo#743654, bgo#764442.
  + Updated translations.
* Mon Mar 21 2016 dimstar@opensuse.org
- Update to version 3.20.0:
  + No code/translation changes.
* Tue Mar 15 2016 dimstar@opensuse.org
- Update to version 3.19.92:
  + bgo#763430: Show additional GAL Attributes in Contacts.
  + Updated translations.
* Mon Feb 29 2016 dimstar@opensuse.org
- Update to version 3.19.91:
  + EEwsNotification: Abort session on idle, to avoid deadlock
    (bgo#760319).
  + Updated translations.
* Tue Feb 16 2016 dimstar@opensuse.org
- Update to version 3.19.90:
  + Contact photos from offline GAL not shown.
  + Do not require gnome-common to run autogen.sh.
  + Correct indentation in e_book_backend_ews_get_contact_list().
  + Bugs fixed: bgo#725320, bgo#761346.
  + Updated translations.
* Tue Feb 16 2016 dimstar@opensuse.org
- Update to version 3.19.4:
  + Updated translations.
* Tue Feb 16 2016 damjanovic.ivo@gmail.com
- Update to version 3.19.3:
  + [Camel] Fill message From header if missing in received MIME
    content.
  + Add <kudos/> into a metainfo file.
  + Visualize incorrect values in an account editor.
  + Bugs fixed: bgo#758375.
  + Updated translations.
* Tue Feb 16 2016 zaitor@opensuse.org
- Update to version 3.19.2:
  + Bugs fixed: bgo#757458, bgo#757477, bgo#757525.
  + Updated translations.
- Changes from version 3.19.1:
  + Show only mail messages in mail folders.
  + Extend error messages in camel_ews_folder_get_message().
  + Bugs fixed: bgo#255032.
  + Updated translations.
- Bump %%define evolution_base_version to 3.20.
* Mon Feb 15 2016 zaitor@opensuse.org
- Update to version 3.18.5:
  + Miscellaneous: Contact photos from offline GAL not shown.
* Mon Jan 18 2016 zaitor@opensuse.org
- Update to version 3.18.4:
  + Updated translations.
* Tue Dec 15 2015 zaitor@opensuse.org
- Update to version 3.18.3:
  + [Camel] Fill message From header if missing in received MIME
    content.
  + Add <kudos/> into a metainfo file.
  + Bugs fixed: bgo#758375.
* Mon Nov  9 2015 zaitor@opensuse.org
- Update to version 3.18.2:
  + Bugs fixed: bgo#757458, bgo#757477, bgo#757525.
  + Updated translations.
* Mon Oct 12 2015 zaitor@opensuse.org
- Update to version 3.18.1:
  + Show only mail messages in mail folders.
* Mon Sep 21 2015 dimstar@opensuse.org
- Update to version 3.18.0:
  + No code/translation changes.
* Mon Sep 14 2015 dimstar@opensuse.org
- Update to version 3.17.92:
  + Do not reuse connections in the source-registry backend.
  + Updated translations.
* Mon Aug 31 2015 zaitor@opensuse.org
- Update to version 3.17.91:
  + Add safety check when replacing folder hierarchy info in hash
    tables.
  + Updated translations.
* Mon Aug 24 2015 fcrozat@suse.com
- Add ews-timezone.patch: Fix evolution-ews's calendar time +1 hour
  in foreign timezone (bsc#924263).
* Mon Aug 17 2015 zaitor@opensuse.org
- Update to version 3.17.90:
  + Avoid %%ld in printf formats.
  + Correct use-after-free in notification code when EWS debugging
    is on.
  + Use only personal mail folders for change notification
    listener.
  + Do not loop in the notification code on fatal client/server
    errors.
  + Bugs fixed: bgo#751703, bgo#233140, bgo#753543.
  + Updated translations.
* Mon Aug 10 2015 zaitor@opensuse.org
- Update to version 3.17.4:
  + Differentiate between Unavailable and No response errors.
  + _ews_debug_dump_raw_soup_message: Check for non-NULL hdrs and
    body arguments.
  + Bugs fixed: bgo#751547, bgo#751725, bgo#692361.
* Mon Aug 10 2015 zaitor@opensuse.org
- Update to version 3.17.3:
  + Remove unused variable.
  + configure.ac: Do not override localedir variable.
  + Use e_source_remove_sync() instead of
    e_source_registry_server_remove_source().
  + Make sure collection child sources are enabled when created.
  + Bugs fixed: bgo#471791, bgo#751001.
- Drop evolution-ews-intltool-path.patch: Fixed upstream.
- Remove gnome-common BuildRequires and call to gnome-autogen.sh,
  no longer needed, also stop intoolizing tarball, patch dropped.
* Mon Aug 10 2015 zaitor@opensuse.org
- Update to version 3.17.2:
  + Correct locking in e_book_backend_ews_set_locale().
  + Address some of the Coverity Scan issues.
  + Bugs fixed: bgo#729989, bgo#671546.
* Mon Aug 10 2015 zaitor@opensuse.org
- Update to version 3.17.1:
  + Use common property lock provided by ESourceExtension.
  + Query auth methods right from the got-headers signal.
  + notification: Try to re-subscribe in case of failure.
  + Move ews_dump_raw_soup_{request,response} to e-ews-debug.[ch].
  + Log the request/response of EEwsNotification.
  + Fix various memory leaks.
  + Bugs fixed: bgo#746395, bgo#748242.
- Bump baseversion following upstream changes.
* Mon Aug 10 2015 zaitor@opensuse.org
- Update to version 3.16.5:
  + Avoid %%ld in printf formats.
  + Use only personal mail folders for change notification
    listener.
  + Bugs fixed: bgo#751703.
* Mon Jul 13 2015 zaitor@opensuse.org
- Update to version 3.16.4:
  + Remove unused variable.
  + configure.ac: Do not override localedir variable.
  + Use e_source_remove_sync() instead of
    e_source_registry_server_remove_source().
  + Make sure collection child sources are enabled when created.
  + Differentiate between Unavailable and No response errors.
  + ews_dump_raw_soup_message: Check for non-NULL hdrs and body
    arguments.
  + Bugs fixed: bgo#471791, bgo#751001, bgo#751547, bgo#751725.
- Drop evolution-ews-intltool-path.patch: Fixed upstream. Also drop
  gnome-common BuildRequires and call to gnome-autogen.sh, as we do
  not have any patches anymore. No longer delete po/Makefile*
  either.
* Tue Jun 30 2015 fcrozat@suse.com
- Add evolution-ews-3.10.4-foreign-calendars-hidden.patch
  (bgo#751547): fix foreign calencards being hidden by default.
- Add evolution-ews-3.10.4-remove-sources.patch: ensure sources are
  properly removed from disk when needed.
* Mon Jun 22 2015 fcrozat@suse.com
- Add
  evolution-ews-3.10.4-Permissions-on-context-menu-for-GAL.patch:
  disable permission context menu on GAL (bgo#751001).
* Mon Jun  8 2015 zaitor@opensuse.org
- Update to version 3.16.3:
  + Correct locking in e_book_backend_ews_set_locale().
  + Address some of the Coverity Scan issues.
- Add evolution-ews-intltool-path.patch: Fix locale installation
  when using recent intltools.
- Delete po/Makefile* to ensure no stale file is left.
- Add gnome-common BuildRequires and call to gnome-autogen.sh, as
  above patch touches the buildsystem.
* Mon May 11 2015 zaitor@opensuse.org
- Update to version 3.16.2:
  + Fix various memory leaks.
  + Bugs fixed: bgo#748242, bgo#729989.
* Mon Apr 13 2015 zaitor@opensuse.org
- Update to version 3.16.1:
  + Query auth methods right from the got-headers signal.
  + notification: Try to re-subscribe in case of failure.
  + Bugs fixed: bgo#746513, bgo#709924, bgo#747500.
* Mon Mar 23 2015 zaitor@opensuse.org
- Update to version 3.16.0:
  + Updated translations.
* Mon Mar 16 2015 dimstar@opensuse.org
- Update to version 3.15.92:
  + Correct 'Listen for server change notification' for books and
    calendars.
  + Mem leak in e_ews_dump_file_attachment_from_soap_parameter().
  + Bugs fixed: bgo#695911, bgo#745457.
  + Updated translations.
* Tue Mar  3 2015 dimstar@opensuse.org
- Update to version 3.15.91:
  + Use thread safe variants of g_object_bind_property*() functions
    from evolution-data-server.
  + Update devel-doc Since from 3.14 to 3.16.
  + Sync version with GNOME 3.15 series.
  + Updated translations.
- Bump evolution_base_version to 16, following upstreams changes.
* Mon Feb 16 2015 dimstar@opensuse.org
- Update to version 3.13.90:
  + Move authentication of backends back to the client.
  + Use automake subdir-objects option.
  + Adapt to camel_session_submit_job() API change.
  + Remove unused declaration of camel_application_is_exiting
    variable.
  + Bugs fixed: bgo#741855, bgo#743705.
  + Updated translations.
* Mon Feb  9 2015 zaitor@opensuse.org
- Update to version 3.13.10:
  + Calendar: Update stored user email after successful connect
    (bgo#729286).
  + Updated translations.
* Mon Feb  9 2015 badshah400@gmail.com
- Update to version 3.13.9:
  + Bugs fixed: bgo#734747, bgo#740772, bgo#695754.
  + Set max-width-chars to wrapped GtkLabel-s.
- Drop evolution-ews-reuse-from-EmailSession.patch, incorporated
  upstream.
- Build dependency on pkgconfig(enchant).
- Upstream no longer installs versioned dirs for evolution, update
  file list accordingly.
* Mon Feb  9 2015 zaitor@opensuse.org
- Update to version 3.12.11 (boo#916784):
  + Avoid/workaround usage of an EAsyncClosure when opening an
    EClient.
  + Bugs fixed: bgo#743959.
  + Updated translations.
* Tue Jan 13 2015 dimstar@opensuse.org
- Update to version 3.12.10:
  + bgo#695754: Reuse existing ESourceRegistry from EMailSession.
  + bgo#729286: [Calendar] Update stored user email after
    successful connect.
- Drop evolution-ews-reuse-from-EmailSession.patch: fixed upstream.
* Sun Dec 14 2014 badshah400@gmail.com
- Update to version 3.12.9:
  + Set max-width-chars to wrapped GtkLabel-s.
  + Bugs fixed: bgo#738945, bgo#738093, bgo#734747, bgo#740772.
- Add post-release fix from upstream:
  + evolution-ews-reuse-from-EmailSession.patch: Reuse existing
    ESourceRegistry from EMailSession, if possible (bgo#695754).
* Tue Nov 11 2014 zaitor@opensuse.org
- Update to version 3.12.8:
  + Use G_IO_ERROR_CANCELLED instead of
    EWS_CONNECTION_ERROR_CANCELLED.
  + Bugs fixed: bgo#738987, bgo#691293.
* Mon Oct 13 2014 dimstar@opensuse.org
- Update to version 3.12.7:
  + Miscellaneous:
  - Update addressbook to use ->open_sync().
  - Use GInitable to initialise addressbook.
  - Port addressbook to EBookSqlite.
  - Fix build for oab-decode-test, port it to EBookSqlite.
  - Move dset handling inside ews_decode_addressbook_record().
  - Use (hashed) PidTagEmailAddress for OAB item UID.
  - Pass GInputStream to decoder functions instead of assuming
    priv->fis.
  - Use GMemoryInputStream for processing records, calculate SHA1
    on each.
  - Optimise EWS GAL update not to rewrite unchanged records.
  - Avoid processing OAB records which already exist.
  - Fix modify_contacts for EBookSqlite.
  - Fix addressbook upgrade from pre-SHA1 versions.
  - Reduce addressbook refresh interval to 6 hours.
  - Avoid using dynamic types for ESourceEwsFolder.
  - Add revision support for addressbook.
  - Add locale support for addressbook.
  - Make ebews_fetch_items() return a list of EContacts not
    EVCards.
  - Refactor ews_update_items_thread() to do all database access
    together.
  - Kill store_to_cache option for ebews_fetch_items().
  - Clean up resync code path in ews_update_items_thread().
  - Use EBookSqlite locking.
  - Fix notification for non-GAL updates to only happen on
    commit.
  - Don't flush the final GAL updates if there are none.
  - Initialise filename to NULL in ews_remove_old_gal_file().
  - Add evolution-ews.metainfo.xml file.
  - Use INTLTOOL_XML_RULE for appdata files.
  + Bugs fixed: bgo#733578, bgo#736257, bgo#737773.
  + Updated translations.
* Mon Sep  8 2014 zaitor@opensuse.org
- Update to version 3.12.6:
  + Bugs Fixed: bgo#735799, bgo#735801.
* Mon Aug 11 2014 zaitor@opensuse.org
- Update to version 3.12.5:
  + Add missing chain-up to parent's constructed() method.
  + Handle cookies (non-persistently).
  + SOUP_STATUS_IS_SUCCESSFUL(soup_session_send_message())
    sends message twice.
  + Clean up enabling/disabling NTLM and Basic auth types.
  + Clean up logging slightly and make it more consistent.
  + Add camel_ews_settings_get_auth_mechanism() helper function.
  + Clean up Negotiate auth implementation to be a SoupAuth
    subclass.
  + Bugs fixed: bgo#733274, bgo#703181, bgo#732850, bgo#703181,
    bgo#733663, bgo#732850, bgo#732850.
* Wed Jul 16 2014 dimstar@opensuse.org
- Update to version 3.12.4:
  + Make Evolution-EWS build under Win32.
  + Bugs fixed: bgo#728942, bgo#730878, bgo#731585.
* Wed Jun 18 2014 zaitor@opensuse.org
- Update to version 3.12.3:
  + Fix g_ascii_strcasecmp: assertion 's2 != NULL'.
  + Fix 'Unintialized pointer read'.
  + Fix 'Uninitialized scalar variable'.
  + Fix 'Logically dead code'.
  + Bugs fixed: bgo#728246, bgo#730042, bgo#692780, bgo#730878.
  + Updated translations.
* Sat May 17 2014 zaitor@opensuse.org
- Update to version 3.12.2:
  + Bugs fixed: Read receipt handling doesn't work (bgo#656805).
  + Updated translations.
* Sun Apr 13 2014 zaitor@opensuse.org
- Update to version 3.12.1:
  + Simplify memory management around ews_sync_mi_flags() function.
  + Bugs fixed: Do not pass NULL text to gtk_entry_set_text()
    bgo#684425.
  + Updated translations.
* Sun Mar 23 2014 zaitor@opensuse.org
- Update to version 3.12.0:
  + No changes since version 3.11.92.
* Fri Mar 14 2014 dimstar@opensuse.org
- Update to version 3.11.92:
  + ECalBackendEws: Do not cause double-free of a GError.
  + Bugs fixed: bgo#726078, bgo#726079.
* Fri Mar 14 2014 dimstar@opensuse.org
- Update to version 3.11.91:
  + configure.ac: Remove evolution-plugin dependency.
  + Bugs fixed: bgo#720260, bgo#724232.
  + Updated translations.
- Drop pkgconfig(evolution-plugin-3.0) BuildRequires: no longer
  required.
* Fri Mar 14 2014 zaitor@opensuse.org
- Update to version 3.11.90:
  + Bugs fixed: bgo#655806, bgo#722416, bgo#722419, bgo#723520.
  + Updated translations.
* Fri Mar 14 2014 dimstar@opensuse.org
- Update to version 3.11.5:
  + Drop KRB5 dependency.
  + Bump minimum libsoup requirement to 2.42.
  + Unit test improvements.
  + Add e_ews_debug_get_server_version_from_string().
  + Abort any pending operations in case notification was cancelled.
  + Bugs fixed: bgo#712179, bgo#721381, bgo#722415.
  + Updated translations.
* Fri Mar 14 2014 dimstar@opensuse.org
- Update to version 3.11.4:
  + Updated translations.
* Fri Mar 14 2014 dimstar@opensuse.org
- Update to version 3.11.3:
  + configure.ac: Do not define EDS_DISABLE_DEPRECATED.
  + Setup the Authentication extension so Camel can determine host
    reachability.
  + Bugs fixed: bgo#664174, bgo#705338, bgo#712255, bgo#712304,
    bgo#715165, bgo#719376.
  + Updated translations.
* Fri Mar 14 2014 dimstar@opensuse.org
- Update to version 3.11.2:
  + Update tar format to tar-ustar.
  + Fix potential issues found by static analysis tools.
  + Bugs fixed: bgo#699349, bgo#708353, bgo#711148, bgo#711470,
    bgo#712304.
  + Updated translations.
* Fri Mar 14 2014 dimstar@opensuse.org
- Update to version 3.11.1:
  + Check for supported authentication methods by the server.
  + Fetch Free/Busy fails due to incorrect value of DayOrder
    element.
  + Bugs fixed: bgo#704869, bgo#708121, bgo#708628.
  + Updated translations.
- Change evolution_base_version t0 3.12.
* Wed Mar 12 2014 zaitor@opensuse.org
- Update to version 3.10.4:
  + Bugs Fixed: bgo#721381, bgo#723520.
  + Updated translations.
* Fri Jan 24 2014 zaitor@opensuse.org
- Update to version 3.10.3:
  + Bugs Fixed: bgo#664174, bgo#719376.
* Mon Nov 11 2013 dimstar@opensuse.org
- Update to version 3.10.2 (bnc#849913):
  + Make offline GAL browsable.
* Mon Oct 14 2013 dimstar@opensuse.org
- Update to version 3.10.1:
  + bgo#706151: Fix crash under
    mail_config_ews_ooo_page_display_settings().
  + bgo#708309: Crash accessing GAL not marked for offline.
  + bgo#708348: Memory leaks from account preferences.
  + Fetch Free/Busy fails due to incorrect value of DayOrder
    element.
  + Updated translations.
* Sat Sep 21 2013 dimstar@opensuse.org
- Update to version 3.10.0:
  + Updated translations.
* Sun Sep 15 2013 zaitor@opensuse.org
- Update to version 3.9.92:
  + Updated translations.
* Mon Sep  2 2013 dimstar@opensuse.org
- Update to version 3.9.91:
  + Bugs fixed: bgo#655325, bgo#656008, bgo#657807, bgo#675796.
  + Updated translations.
* Sun Aug 18 2013 zaitor@opensuse.org
- Update to version 3.9.90:
  + Bugs fixed: bgo#654528, bgo#660748, bgo#675737, bgo#681741,
    bgo#699558, bgo#704772, bgo#704914, bgo#704940, bgo#705118,
    bgo#705337, bgo#705617, bgo#705658.
  + Updated translations.
* Mon Jul 29 2013 dimstar@opensuse.org
- Update to version 3.9.5:
  + Add E_CONTACT_OFFICE parsing for GAL.
  + Add some more GAL field types seen in the wild.
  + Use GBytes for GAL binary properties.
  + Add X509 cert from GAL.
  + Add E_CONTACT_WANTS_HTML from GAL.
  + Fix hang on multiple contacts removal.
  + Bugs fixed: bgo#386113, bgo#659700, bgo#702035, bgo#703181,
    bgo#703832, bgo#704370, bgo#704618.
  + Updated translations.
* Mon Jul  8 2013 dimstar@opensuse.org
- Update to version 3.9.4:
  + Fix leak and avoid to pass NULL to g_strrstr().
  + Fix segfault: set text as NULL when both g_strrstr() fails.
  + Use g_strcmp0 instead of implement it as check_equal.
  + Allow to pass NULL for e_ews_connection_get_folder_sync.
  + Bugs fixed: bgo#702922, bgo#703053, bgo#703194.
  + Updated translations.
* Fri Jun 21 2013 dimstar@opensuse.org
- Update to version 3.9.3:
  + e-ews-search-user: Do not print console error when nothing
    found.
  + Fetch fresh folder's change-key, when reading folder
    permissions.
  + Check for cancellation when refreshing folder content.
  + Require --with-internal-lzx for libmspack fallback.
  + Disable incremental GAL updates without libmspack.
  + Fix various memory leaks.
  + Make the statements explicit when using ternary if.
  + Bugs fixed: bgo#701246.
  + Updated translations.
* Sun May 26 2013 dimstar@opensuse.org
- Update to version 3.9.2:
  + Handle inlined attachments in
    e_ews_connection_{create,get}_attachments.
  + Handle absence of ETag.
  + Update LZX decompressor.
  + Allow upstream libmspack to be used, if it's new enough.
  + Allow e_ews_connection_get_oal_detail() to return more than one
    type of element.
  + Fix crash on addressbook close.
  + Don't remove OAB file after processing.
  + Implement incremental GAL download.
  + Use "X-EWS-KIND" attribute.
  + Bugs fixed: bgo#654950, bgo#658892, bgo#673351, bgo#698728,
    bgo#699231, bgo#699241, bgo#699373, bgo#699481, bgo#699847.
  + Updated translations.
- Add pkgconfig(libmspack) BuildRequires: new dependency.
- Drop liblzx0 subpackage: this was a wrapper around libmspack
  functionality, where the fixes were merged in this code. As per
  SLPP, we do not obsolete the library.
* Mon Apr 29 2013 dimstar@opensuse.org
- Update to version 3.9.1:
  + Bugs fixed: bgo#670939, bgo#686227, bgo#691937, bgo#696092,
    bgo#696221.
  + Updated translations.
* Mon Apr 15 2013 dimstar@opensuse.org
- Update to version 3.8.1:
  + Make enum type registration thread safe (bgo#681837).
  + Error is shown when a folder is created in the root (same level
    than "Inbox") (bgo#695921).
* Sun Mar 24 2013 zaitor@opensuse.org
- Update to version 3.8.0:
  + No changes since 3.7.92.
* Sun Mar 17 2013 dimstar@opensuse.org
- Update to version 3.7.92:
  + Bugs fixed: bgo#654953, bgo#690433, bgo#695177, bgo#695311,
    bgo#695707.
* Sun Mar  3 2013 dimstar@opensuse.org
- Update to version 3.7.91:
  + Be more forgiving with the invitation response status pairing.
  + Listen and act on EBackend's online state changes.
  + Claim sources even when in offline.
  + Bugs fixed: bgo#693345.
  + Updated translations.
* Mon Feb 18 2013 dimstar@opensuse.org
- Update to version 3.7.90:
  + Bugs fixed: bgo#668489, bgo#693012, bgo#693306.
  + Updated translations.
* Tue Feb  5 2013 dimstar@opensuse.org
- Update to version 3.7.5:
  + Support for public folders (bgo#656377).
  + Bugs fixed: bgo#690474, bgo#692688, bgo#692705.
  + Updated translations.
* Fri Jan 25 2013 dimstar@opensuse.org
- Update to version 3.7.4:
  + Updated translations.
* Thu Jan 24 2013 dimstar@opensuse.org
- Update to version 3.7.3.1:
  + Removed dependency on libedataserverui-3.0.
- Changes from version 3.7.3:
  + Unsubscribe should remove also subfolders, if subscribed with
    them
  + Read also CalendarEventDetails from Free/Busy response
  + Use version-based GLib/GDK/GTK+ warnings.
  + Bump GLib requirement to 2.32.
  + Do not generate a ChangeLog file from 'git log'
  + Bugs fixed: bgo#671893, bgo#677888, bgo#687874, bgo#689521.
  + Updated translations.
- Drop pkgconfig(libedataserverui-3.0) BuildRequires: the library
  no longer exists.
* Wed Jan 23 2013 dimstar@opensuse.org
- Update to version 3.7.2:
  + Allow changing permissions of a Calendar folder.
  + Fix XML parsing failure during Free/Busy fetching.
  + Generate a ChangeLog file in tarballs.
  + Bugs fixed: bgo#686024, bgo#686228, bgo#681665, bgo#687228,
    bgo#687877, bgo#686227, bgo#685795, bgo#685795.
  + Updated translations.
* Wed Jan 23 2013 dimstar@opensuse.org
- Update to version 3.7.1:
  + Fix crash under oal_response_cb() (bgo#686268)
  + Updated translations.
* Tue Jan 22 2013 dimstar@opensuse.org
- Update to version 3.6.3:
  + Bugs fixed: bgo#671893, bgo#687874, bgo#689521, bgo#690474.
  + Updated translations.
* Tue Nov 13 2012 dimstar@opensuse.org
- Update to version 3.6.1:
  + Allow changing permissions of a Calendar folder.
  + Fix XML parsing failure during Free/Busy fetching.
  + Bugs fixed: bgo#681665, bgo#686024, bgo#686227, bgo#686228,
    bgo#686268, bgo#687228.
  + Updated translations.
* Sun Sep 23 2012 zaitor@opensuse.org
- Update to version 3.6.0:
  + Updated translations.
* Sun Sep 16 2012 dimstar@opensuse.org
- Update to version 3.5.92:
  + Make translations work in respective modules
  + Bugs fixed: bgo#655774, bgo#680921, bgo#682914
  + Updated translations.
* Sun Sep  2 2012 dimstar@opensuse.org
- Update to version 3.5.91:
  + Implement CamelFolder::get_message_cached()
  + Do not update folder structure in source registry for disabled
    accounts
  + Do not overwrite user's changes on GAL ESource
  + Various other code changes.
  + Bugs fixed: bgo#675730, bgo#682020
  + Updated translations.
* Sun Aug 19 2012 dimstar@opensuse.org
- Update to version 3.5.90:
  + Add version information to CamelEwsStoreSummary
  + Implement "Subscribe to folder of other user" feature
  + Set CamelEwsSettings::email on successful autodiscover
  + Re-add foreign calendar/tasks/book sources on initial
    collection setup
  + Do not add owner's folders under 'Mailbox - User Name' folder
  + Bugs fixed:
  - bgo#674321: Support for password expiration information
  - bgo#670458, bgo#681544
  + Updated translations.
* Tue Aug 14 2012 dimstar@opensuse.org
- Update to version 3.5.5:
  + Support remote folder creation and deletion
  + Finish rewriting the "Out of Office" config page
  + Be able to read/write folder permissions
  + Do not save unchanged Out-Of-Office settings
  + Various other code changes.
  + Bugs fixed:
  - bgo#656376: Support for delegation
  - bgo#656709, bgo#665986, bgo#669460 bgo#670506, bgo#673095,
    bgo#675285, bgo#675442, bgo#678464 bgo#680153, bgo#680525,
    bgo#680683, bgo#680960
  + Updated translations.
* Tue Aug 14 2012 dimstar@opensuse.org
- Update to version 3.5.4:
  + Fix crasher in oal_response_cb()
  + Add "Connection timeout" option into mail account properties
  + Rework SOAP response handling
  + Bugs fixed:
  - bgo#677007: Add Basic authentication type
  - bgo#663383, bgo#679303, bgo#679305.
* Tue Aug 14 2012 dimstar@opensuse.org
- Update to version 3.5.3:
  + Drop gconf-2.0 dependency.
  + Bump minimum gtk+-3.0 requirement to 3.0.
  + Various other code changes.
  + Bugs fixed: bgo#654543, bgo#673408, bgo#674599, bgo#676081,
    bgo#677398, bgo#677531, bgo#678321.
  + Updated translations.
- Drop pkgconfig(gconf-2.0) BuildRequires: dependency dropped
  upstream.
- Add pkgconfig(evolution-mail-3.0) BuildRequires: configure now
  checks for it.
* Tue Aug 14 2012 dimstar@opensuse.org
- Update to version 3.5.1:
  + Fix compiler warning for portability
  + Various other code changes.
  + Bugs fixed: bgo#659717, bgo#661979, bgo#668555, bgo#670457,
    bgo#670944, bgo#671624, bgo#672175, bgo#672448, bgo#672448.
  + Updated translations.
- Drop xz BuildRequires as it now comes for free in the build
  system.
* Tue Aug 14 2012 dimstar@opensuse.org
- Update to version 3.4.4:
  + Crash when failed to get a message from a server (bgo#665986)
  + Unable to accept meeting request (bgo#670458)
  + Bugs fixed: bgo#656709, bgo#663383, bgo#668555, bgo#669460,
    bgo#670506, bgo#673095, bgo#675285, bgo#675442, bgo#678321,
    bgo#679303, bgo#679305, bgo#680153, bgo#680525, bgo#680683.
* Mon Jun 18 2012 dimstar@opensuse.org
- Update to version 3.4.3:
  + Mark as junk doesn't work (bgo#654543)
  + Deleted message not deleted from server (bgo#676081)
  + Bugs fixed: bgo#673408, bgo#674599, bgo#677007, bgo#677398,
    bgo#677531.
* Mon May 14 2012 vuntz@opensuse.org
- Update to version 3.4.2:
  + Report errors from backends in their error domain
  + Fix possible crash at the end of autodiscovery
  + Bugs fixed:
  - bgo#653631: Empty trash doesn't work
  - bgo#664637: Deleted messages appear in Inbox
* Tue Apr 17 2012 vuntz@opensuse.org
- Update to version 3.4.1:
  + Bugs fixed: bgo#661436, bgo#670217, bgo#671969, bgo#673349.
* Mon Mar 26 2012 vuntz@opensuse.org
- Update to version 3.4.0:
  + Updated translations.
* Tue Mar 20 2012 vuntz@opensuse.org
- Update to version 3.3.92:
  + Suppress deprecation warnings.
  + Various other code changes.
  + Bugs fixed: bgo#660428, bgo#665801, bgo#667849.
* Tue Mar  6 2012 vuntz@opensuse.org
- Update to version 3.3.91:
  + Updated translations.
* Mon Feb 20 2012 dimstar@opensuse.org
- Update to version 3.3.90:
  + Bugs fixed:
  - bgo#656375: Implement Out of Office
  - bgo#668174: Fix creation of appointments and meetings
  - bgo#654810, bgo#654810, bgo#654822, bgo#658347, bgo#664749,
    bgo#665801, bgo#669338.
  + Updated translations.
* Sun Feb  5 2012 dimstar@opensuse.org
- Update to version 3.3.5:
  + Adapt to libemail-engine.
- Add pkgconfig(libemail-engine) BuildRequires, folloing the code
  changes.
* Mon Jan 16 2012 vuntz@opensuse.org
- Update to version 3.3.4:
  + Bugs fixed:
  - bgo#665104: Possible memory leaks
  - bgo#665533: OAB caching not working
  - bgo#667185: Menu items from plugins not translated
  + Updated translations.
* Tue Dec 20 2011 vuntz@opensuse.org
- Update to version 3.3.3:
  + Fix address-book to display contents without error.
  + Implement GetFolder request.
  + Remove all *_DISABLE_DEPRECATED_FLAGS.
  + Remove GSEAL_ENABLE macro.
  + Bugs fixed:
  - bgo#656376: Support for delegation
  - bgo#664637: Deleted messages appear in Inbox
  - bgo#648877, bgo#654940, bgo#659679, bgo#661537, bgo#663379,
    bgo#664116, bgo#664572, bgo#665065.
  + Updated translations.
- Add xz BuildRequires because we can't build a package for a
  xz-compressed tarball without explicitly specifying that... See
  bnc#697467 for more details.
- Drop change-compiler-flag-dimstar.patch: fixed upstream. Also
  remove gnome-common BuildRequires and call to gnome-autogen.sh
  that were needed for the patch.
* Mon Nov 21 2011 dimstar@opensuse.org
- Update to version 3.3.2:
  + Remove g_thread_init() calls.
  + Do not use deprecated g_atexit.
  + Bugs fixed: bgo#657320, bgo#661528, bgo#661972, bgo#662598.
  + Updated translations.
- Changes from version 3.3.1.1:
  + Work around libgthread shenanigans in GLib 2.31.
- Changes from version 3.3.1:
  + Adapt to various API changes.
  + Prefill Host URL when creating new account
  + Use SHA256 of EWS ItemId for cache filename, not the ItemId
    itself.
  + Updated translations.
- Enhance change-compiler-flag-dimstar.patch: Remove usage of
  G_DISABLE_DEPRECATED from the build.
- Drop base-version-changed.patch: fixed upstream.
* Fri Oct 14 2011 vuntz@opensuse.org
- Cleanup for inclusion in Factory.
* Fri Oct 14 2011 jpunit@suse.com
- Patches added:
  + Changed compiler flag (Dimstar)
* Mon Oct 10 2011 jpunit@suse.com
- Patches added:
  + Base version changed to 3.2
* Fri Oct  7 2011 jpunit@suse.com
- First submission of evolution-ews
